Learn R Programming

gemma2 (version 0.1.3)

calc_omega: Calculate Omega matrices

Description

Calculate Omega matrices

Usage

calc_omega(eval, D_l)

Arguments

eval

vector of eigenvalues from decomposition of relatedness matrix

D_l

vector of length d_size

Value

list of length 2. First entry in the list is the symmetric matrix OmegaU. Second entry in the list is the symmetric matrix OmegaE.

Examples

Run this code
# NOT RUN {
calc_omega(eval = 50:1, D_l = runif(2))
# }

Run the code above in your browser using DataLab