powered by
Calculate Omega matrices
calc_omega(eval, D_l)
vector of eigenvalues from decomposition of relatedness matrix
vector of length d_size
list of length 2. First entry in the list is the symmetric matrix OmegaU. Second entry in the list is the symmetric matrix OmegaE.
# NOT RUN { calc_omega(eval = 50:1, D_l = runif(2)) # }
Run the code above in your browser using DataLab